commbds

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 13, 2023 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Bds

type Bds struct {
	TransponderRegisterNumber string          `json:"transponderRegisterNumber"`
	Code00                    *string         `json:"code00,omitempty"`
	Code40                    *bdscode.Code40 `json:"code40,omitempty"`
	Code50                    *bdscode.Code50 `json:"code50,omitempty"`
	Code60                    *bdscode.Code60 `json:"code60,omitempty"`
	CodeNotProcessed          *string         `json:"codeNotProcessed,omitempty"`
}

Bds Comm-B Data Selector. ICAO Doc 9871: Technical Provisions for Mode S Services and Extended Squitter The 8-bit BDS code determines the transponder register whose contents are to be transferred in the MB field of a Comm-B reply. It is expressed in two groups of 4 bits each, BDS1 (most significant 4 bits) and BDS2 (least significant 4 bits) Ref. Technical Provisions for Mode S Services and Extended Squitter MB = Message Comm-B TransponderRegisterNumber: BDS1 + BDS2 Code00: Not valid Code40: Selected vertical intention Code50: Track and turn report Code60: Heading and speed report CodeNotProcessed: code bds undefined return hex string value

func (*Bds) Decode

func (ds *Bds) Decode(data [8]byte) (err error)

Decode reads a BDS fields data of 8 bytes = BDS fields 7 bytes + code 1 byte

Directories

Path Synopsis

Jump to